summaryrefslogtreecommitdiff
path: root/mkspecs/solaris-cc/qplatformdefs.h
Side-by-side diff
Diffstat (limited to 'mkspecs/solaris-cc/qplatformdefs.h') (more/less context) (ignore whitespace changes)
-rw-r--r--mkspecs/solaris-cc/qplatformdefs.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/mkspecs/solaris-cc/qplatformdefs.h b/mkspecs/solaris-cc/qplatformdefs.h
index f9480a9..9506b3c 100644
--- a/mkspecs/solaris-cc/qplatformdefs.h
+++ b/mkspecs/solaris-cc/qplatformdefs.h
@@ -8,2 +8,3 @@
// Set any POSIX/XOPEN defines at the top of this file to turn on specific APIs
+#define _POSIX_PTHREAD_SEMANTICS
@@ -79,5 +80,7 @@
#if !defined(_XOPEN_UNIX)
// Function usleep() is in C library but not in header files on Solaris 2.5.1.
// Not really a surprise, usleep() is specified by XPG4v2 and XPG4v2 is only
// supported by Solaris 2.6 and better.
// So we are trying to detect Solaris 2.5.1 using macro _XOPEN_UNIX which is
@@ -86,2 +89,3 @@ typedef unsigned int useconds_t;
extern "C" int usleep(useconds_t);
+extern "C" int gethostname(char *, int);
#endif
@@ -79,5 +80,7 @@
#if !defined(_XOPEN_UNIX)
-// Function usleep() is in C library but not in header files on Solaris 2.5.1.
-// Not really a surprise, usleep() is specified by XPG4v2 and XPG4v2 is only
-// supported by Solaris 2.6 and better.
+// Function usleep() is defined in C library but not declared in header files
+// on Solaris 2.5.1. Not really a surprise, usleep() is specified by XPG4v2
+// and XPG4v2 is only supported by Solaris 2.6 and better.
+// Function gethostname() is defined in C library but not declared in <unistd.h>
+// on Solaris 2.5.1.
// So we are trying to detect Solaris 2.5.1 using macro _XOPEN_UNIX which is